@@ -7,9 +7,9 @@
 
 #ifdef HAVE_RUBY_ENCODING_H
 #	include <ruby/encoding.h>
-#	define redcarpet_str_new(data, size) rb_enc_str_new(data, size, rb_utf8_encoding())
+#	define redcarpet_str_new(data, size, enc) rb_enc_str_new(data, size, enc)
 #else
-#	define redcarpet_str_new(data, size) rb_str_new(data, size)
+#	define redcarpet_str_new(data, size, enc) rb_str_new(data, size)
 #endif
 
 #include "markdown.h"
@@ -21,8 +21,12 @@ extern void Init_redcarpet_rndr();
 
 struct redcarpet_renderopt {
 	struct html_renderopt html;
+	VALUE link_attributes;
 	VALUE self;
 	VALUE base_class;
+#ifdef HAVE_RUBY_ENCODING_H
+	rb_encoding *active_enc;
+#endif
 };
 
 struct rb_redcarpet_rndr {
